"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[6640],{16640:(e,o)=>{var r;Object.defineProperty(o,"__esModule",{value:!0}),o.LogLevel=void 0,(r=o.LogLevel||(o.LogLevel={})).Error="ERROR",r.Warning="WARNING",r.Info="INFO",r.Debug="DEBUG"}}]);
//# sourceMappingURL=6640.2badf0e09b393fe70fc3.js.map