"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[6891],{36891:(r,t,e)=>{e.r(t),e.d(t,{__DO_NOT_USE__ActionTypes:()=>p,applyMiddleware:()=>w,bindActionCreators:()=>b,combineReducers:()=>l,compose:()=>v,createStore:()=>a,legacy_createStore:()=>y});var n=e(64649);function o(r,t){var e=Object.keys(r);if(Object.getOwnPropertySymbols){var n=Object.getOwnPropertySymbols(r);t&&(n=n.filter((function(t){return Object.getOwnPropertyDescriptor(r,t).enumerable}))),e.push.apply(e,n)}return e}function i(r){for(var t=1;t<arguments.length;t++){var e=null!=arguments[t]?arguments[t]:{};t%2?o(Object(e),!0).forEach((function(t){(0,n.Z)(r,t,e[t])})):Object.getOwnPropertyDescriptors?Object.defineProperties(r,Object.getOwnPropertyDescriptors(e)):o(Object(e)).forEach((function(t){Object.defineProperty(r,t,Object.getOwnPropertyDescriptor(e,t))}))}return r}function u(r){return"Minified Redux error #"+r+"; visit https://redux.js.org/Errors?code="+r+" for the full message or use the non-minified dev environment for full errors. "}var f="function"==typeof Symbol&&Symbol.observable||"@@observable",c=function(){return Math.random().toString(36).substring(7).split("").join(".")},p={INIT:"@@redux/INIT"+c(),REPLACE:"@@redux/REPLACE"+c(),PROBE_UNKNOWN_ACTION:function(){return"@@redux/PROBE_UNKNOWN_ACTION"+c()}};function a(r,t,e){var n;if("function"==typeof t&&"function"==typeof e||"function"==typeof e&&"function"==typeof arguments[3])throw new Error(u(0));if("function"==typeof t&&void 0===e&&(e=t,t=void 0),void 0!==e){if("function"!=typeof e)throw new Error(u(1));return e(a)(r,t)}if("function"!=typeof r)throw new Error(u(2));var o=r,i=t,c=[],y=c,l=!1;function s(){y===c&&(y=c.slice())}function b(){if(l)throw new Error(u(3));return i}function v(r){if("function"!=typeof r)throw new Error(u(4));if(l)throw new Error(u(5));var t=!0;return s(),y.push(r),function(){if(t){if(l)throw new Error(u(6));t=!1,s();var e=y.indexOf(r);y.splice(e,1),c=null}}}function w(r){if(!function(r){if("object"!=typeof r||null===r)return!1;for(var t=r;null!==Object.getPrototypeOf(t);)t=Object.getPrototypeOf(t);return Object.getPrototypeOf(r)===t}(r))throw new Error(u(7));if(void 0===r.type)throw new Error(u(8));if(l)throw new Error(u(9));try{l=!0,i=o(i,r)}finally{l=!1}for(var t=c=y,e=0;e<t.length;e++)(0,t[e])();return r}return w({type:p.INIT}),(n={dispatch:w,subscribe:v,getState:b,replaceReducer:function(r){if("function"!=typeof r)throw new Error(u(10));o=r,w({type:p.REPLACE})}})[f]=function(){var r,t=v;return(r={subscribe:function(r){if("object"!=typeof r||null===r)throw new Error(u(11));function e(){r.next&&r.next(b())}return e(),{unsubscribe:t(e)}}})[f]=function(){return this},r},n}var y=a;function l(r){for(var t=Object.keys(r),e={},n=0;n<t.length;n++){var o=t[n];"function"==typeof r[o]&&(e[o]=r[o])}var i,f=Object.keys(e);try{!function(r){Object.keys(r).forEach((function(t){var e=r[t];if(void 0===e(void 0,{type:p.INIT}))throw new Error(u(12));if(void 0===e(void 0,{type:p.PROBE_UNKNOWN_ACTION()}))throw new Error(u(13))}))}(e)}catch(r){i=r}return function(r,t){if(void 0===r&&(r={}),i)throw i;for(var n=!1,o={},c=0;c<f.length;c++){var p=f[c],a=e[p],y=r[p],l=a(y,t);if(void 0===l)throw t&&t.type,new Error(u(14));o[p]=l,n=n||l!==y}return(n=n||f.length!==Object.keys(r).length)?o:r}}function s(r,t){return function(){return t(r.apply(this,arguments))}}function b(r,t){if("function"==typeof r)return s(r,t);if("object"!=typeof r||null===r)throw new Error(u(16));var e={};for(var n in r){var o=r[n];"function"==typeof o&&(e[n]=s(o,t))}return e}function v(){for(var r=arguments.length,t=new Array(r),e=0;e<r;e++)t[e]=arguments[e];return 0===t.length?function(r){return r}:1===t.length?t[0]:t.reduce((function(r,t){return function(){return r(t.apply(void 0,arguments))}}))}function w(){for(var r=arguments.length,t=new Array(r),e=0;e<r;e++)t[e]=arguments[e];return function(r){return function(){var e=r.apply(void 0,arguments),n=function(){throw new Error(u(15))},o={getState:e.getState,dispatch:function(){return n.apply(void 0,arguments)}},f=t.map((function(r){return r(o)}));return n=v.apply(void 0,f)(e.dispatch),i(i({},e),{},{dispatch:n})}}}},64649:(r,t,e)=>{e.d(t,{Z:()=>o});var n=e(55217);function o(r,t,e){return(t=(0,n.Z)(t))in r?Object.defineProperty(r,t,{value:e,enumerable:!0,configurable:!0,writable:!0}):r[t]=e,r}},55217:(r,t,e)=>{e.d(t,{Z:()=>o});var n=e(33940);function o(r){var t=function(r,t){if("object"!==(0,n.Z)(r)||null===r)return r;var e=r[Symbol.toPrimitive];if(void 0!==e){var o=e.call(r,"string");if("object"!==(0,n.Z)(o))return o;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(r)}(r);return"symbol"===(0,n.Z)(t)?t:String(t)}},33940:(r,t,e)=>{function n(r){return n="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(r){return typeof r}:function(r){return r&&"function"==typeof Symbol&&r.constructor===Symbol&&r!==Symbol.prototype?"symbol":typeof r},n(r)}e.d(t,{Z:()=>n})}}]);
//# sourceMappingURL=6891.1b1c37acadfa9bc7bffb.js.map