"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[3639],{26452:(e,t,a)=>{a.d(t,{Z:()=>k});var n=a(86332),s=a.n(n),c=a(84390),l=a.n(c),r=a(72060),o=a(9448),i=a(60042),u=a.n(i);const m=e=>{let{url:t,className:a,onClick:n}=e;const{formatMessage:s}=(0,r.useIntl)();return l().createElement("div",{className:u()("signup-header",a)},l().createElement(o.Link,{"data-testid":"back_button",onClick:n,to:t},l().createElement("span",{id:"back_button_icon",className:"fa fa-1x fa-angle-left",title:s({id:"generic_icons.back",defaultMessage:"Back Icon"})}),l().createElement(r.FormattedMessage,{id:"web.header.back",defaultMessage:"Back"})))};m.propTypes={url:s().string,className:s().string,onClick:s().func},m.defaultProps={url:"/"};const k=m},73639:(e,t,a)=>{a.r(t),a.d(t,{default:()=>d});var n=a(86332),s=a.n(n),c=a(84390),l=a.n(c),r=a(9448),o=a(70314),i=a(26452),u=a(573),m=a(19601);const k=e=>{let{alternateLink:t,backButtonURL:a,onBackButtonClick:n}=e;const{EnableCustomBrand:s,SiteName:c}=(0,o.useSelector)(m.iE),k="true"===s&&c?c:"Mattermost";return l().createElement("div",{className:"hfroute-header"},l().createElement("div",{className:"header-main"},l().createElement(r.Link,{className:"header-logo-link",to:"/","aria-label":k},"true"===s||"Mattermost"!==c?c:l().createElement(u.Z,null)),t),n&&l().createElement(i.Z,{className:"header-back-button",url:a,onClick:n}))};k.propTypes={alternateLink:s().element,backButtonURL:s().string,onBackButtonClick:s().func};const d=k}}]);
//# sourceMappingURL=3639.6441bc756774b3362581.js.map