"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[5904],{25904:(e,t,o)=>{o.r(t),o.d(t,{default:()=>h});var r,n,i,a=o(70314),c=o(19601),s=(o(92189),o(86332)),l=o.n(s),p=o(84390),m=o.n(p),f=o(35683),u=o(70174);class d extends m().PureComponent{componentDidMount(){document.body.classList.add("sticky");const e=document.getElementById("root");e&&e.classList.add("container-fluid")}componentWillUnmount(){document.body.classList.remove("sticky");const e=document.getElementById("root");e&&e.classList.remove("container-fluid")}render(){const e=[];return this.props.config?(this.props.config.AboutLink&&e.push(m().createElement(f.Z,{key:"about_link",id:"about_link",className:"footer-link",location:"header_footer_template",href:this.props.config.AboutLink},(0,u._u)("web.footer.about","About"))),this.props.config.PrivacyPolicyLink&&e.push(m().createElement(f.Z,{key:"privacy_link",id:"privacy_link",className:"footer-link",location:"header_footer_template",href:this.props.config.PrivacyPolicyLink},(0,u._u)("web.footer.privacy","Privacy Policy"))),this.props.config.TermsOfServiceLink&&e.push(m().createElement(f.Z,{key:"terms_link",id:"terms_link",className:"footer-link",location:"header_footer_template",href:this.props.config.TermsOfServiceLink},(0,u._u)("web.footer.terms","Terms"))),this.props.config.HelpLink&&e.push(m().createElement(f.Z,{key:"help_link",id:"help_link",className:"footer-link",location:"header_footer_template",href:this.props.config.HelpLink},(0,u._u)("web.footer.help","Help"))),m().createElement("div",{className:"inner-wrap"},m().createElement("div",{className:"row content"},this.props.children),m().createElement("div",{className:"row footer"},m().createElement("div",{id:"footer_section",className:"footer-pane col-xs-12"},m().createElement("div",{className:"col-xs-12"},m().createElement("span",{id:"company_name",className:"pull-right footer-site-name"},"Mattermost")),m().createElement("div",{className:"col-xs-12"},m().createElement("span",{id:"copyright",className:"pull-right footer-link copyright"},"© 2015-".concat((new Date).getFullYear()," Mattermost, Inc.")),m().createElement("span",{className:"pull-right"},e)))))):null}}r=d,n="propTypes",i={children:l().object,config:l().object},(n=function(e){var t=function(e,t){if("object"!=typeof e||null===e)return e;var o=e[Symbol.toPrimitive];if(void 0!==o){var r=o.call(e,"string");if("object"!=typeof r)return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}(e);return"symbol"==typeof t?t:String(t)}(n))in r?Object.defineProperty(r,n,{value:i,enumerable:!0,configurable:!0,writable:!0}):r[n]=i;const h=(0,a.connect)((function(e){return{config:(0,c.iE)(e)}}))(d)}}]);
//# sourceMappingURL=5904.b41af8d748e61010165f.js.map