@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.DelinquencyModal .modal-dialog{position:absolute;top:50%;left:50%;margin:auto;transform:translate(-50%, -50%) !important}.DelinquencyModal .modal-content{max-width:512px;max-height:465px;border-radius:12px}.DelinquencyModal .modal-header{border-radius:12px 12px 0 0}.DelinquencyModal .modal-footer{padding-top:24px;padding-bottom:24px;border-radius:0 0 12px 12px}.DelinquencyModal .modal-header,.DelinquencyModal .modal-footer{display:flex;padding-right:32px;padding-left:32px}.DelinquencyModal .DelinquencyModal__header{align-items:center;border:none}.DelinquencyModal .DelinquencyModal__header.modal-header{background:var(--center-channel-bg)}.DelinquencyModal .DelinquencyModal__header h3{margin:0;color:#3f4350;font-size:22px;font-weight:bold;line-height:28px}.DelinquencyModal .DelinquencyModal__header .icon-close{height:40px;padding:0 20px;font-size:14px;line-height:14px;padding:0;border:none;margin-left:auto;background:var(--center-channel-bg);color:#3f4350;font-size:24px}.DelinquencyModal .modal-body{display:block;overflow:hidden;max-height:none;padding:0 32px;margin-bottom:28px;color:#3f4350}.DelinquencyModal__body{text-align:center}.DelinquencyModal__body__freemium{text-align:left}.DelinquencyModal__body__title{margin-bottom:8px;font-size:22px;font-weight:bold;line-height:28px}.DelinquencyModal__body__information{margin:0;font-size:12px}.DelinquencyModal__body__limits-information{margin:0;margin-bottom:24px;font-size:12px}.DelinquencyModal__body__subheader{display:block;margin-bottom:16px;color:rgba(63,67,80,.56);font-size:10px;font-weight:bold;text-transform:uppercase}.DelinquencyModal__footer--secondary{display:inline-flex;align-items:center;border:0;background:rgba(var(--button-bg-rgb), 0.08);border-radius:4px;color:var(--button-bg);font-weight:600;transition:all .15s ease-out;height:48px;padding:0 24px;font-size:16px;line-height:18px}.DelinquencyModal__footer--secondary:disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.DelinquencyModal__footer--secondary:hover:enabled{background:rgba(var(--button-bg-rgb), 0.12)}.DelinquencyModal__footer--secondary:active:enabled{background:rgba(var(--button-bg-rgb), 0.16)}.DelinquencyModal__footer--secondary i{display:flex;font-size:18px}.DelinquencyModal__footer--secondary i:first-child::before{margin:0 7px 0 0}.DelinquencyModal__footer--secondary i:last-child::before{margin:0 0 0 7px}.DelinquencyModal__footer--primary{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;background:var(--button-bg);border-radius:4px;color:var(--button-color);font-weight:600;transition:all .15s ease-out;height:48px;padding:0 24px;font-size:16px;line-height:18px;margin-left:auto}.DelinquencyModal__footer--primary:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.DelinquencyModal__footer--primary:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.DelinquencyModal__footer--primary:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.DelinquencyModal__footer--primary:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.DelinquencyModal__footer--primary i{display:flex;font-size:18px}

/*# sourceMappingURL=5960.13c43b09e5d97980d3b5.css.map*/